==> 0.0.2.tar.gz: android/src/main/java/com/mobcodes/microsoft_appcenter_flutter/MicrosoftAppcenterFlutterPlugin.java <==
package com.mobcodes.microsoft_appcenter_flutter;

import android.app.Application;

import androidx.annotation.NonNull;

import com.microsoft.appcenter.AppCenter;
import com.microsoft.appcenter.analytics.Analytics;
import com.microsoft.appcenter.crashes.Crashes;
import com.microsoft.appcenter.utils.async.AppCenterConsumer;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.UUID;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;

/** MicrosoftAppcenterFlutterPlugin */
public class MicrosoftAppcenterFlutterPlugin implements FlutterPlugin, MethodCallHandler {
  /// The MethodChannel that will the communication between Flutter and native Android
  ///
  /// This local reference serves to register the plugin with the Flutter Engine and unregister it
  /// when the Flutter Engine is detached from the Activity
  private MethodChannel channel;

  private Registrar registrar;

  private MicrosoftAppcenterFlutterPlugin(Registrar registrar) {
    this.registrar = registrar;
  }

  @Override
  public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
    channel = new MethodChannel(flutterPluginBinding.getBinaryMessenger(), "microsoft_appcenter_flutter");
    channel.setMethodCallHandler(this);
  }

  @Override
  public void onMethodCall(@NonNull MethodCall call, @NonNull final Result result) {
    if (call.method.equals("getPlatformVersion")) {
      result.success("Android " + android.os.Build.VERSION.RELEASE);
    } else {
      result.notImplemented();
    }

    Application app = this.registrar.activity().getApplication();

    switch (call.method) {
      case "installId":
        AppCenter.getInstallId().thenAccept(new AppCenterConsumer<UUID>() {
          @Override
          public void accept(UUID uuid) {
            result.success(uuid.toString());
          }
        });

        break;
      case "isEnabled":
        AppCenter.isEnabled().thenAccept(new AppCenterConsumer<Boolean>() {
          @Override
          public void accept(Boolean enabled) {
            result.success(enabled.booleanValue());
          }
        });

        break;
      case "setEnabled":
        Boolean isEnabled = call.argument("isEnabled");
        AppCenter.setEnabled(isEnabled).thenAccept(new AppCenterConsumer<Void>() {
          @Override
          public void accept(Void v) {
            result.success(null);
          }
        });
        break;
      case "configure":
        String secret = call.argument("app_secret");
        AppCenter.configure(app, secret);
        result.success(null);
        break;
      case "start":
        String start_secret = call.argument("app_secret");
        List<String> services = call.argument("services");
        List<Class> servicesClasses = new ArrayList<>();
        for (String name : services) {
          try {
            Class c = Class.forName(name);
            servicesClasses.add(c);
          }
          catch(ClassNotFoundException notFound) {
            System.out.print(notFound.getException().toString());
          }
        }

        Class[] servicesClassesArray = new Class[servicesClasses.size()];
        servicesClassesArray = servicesClasses.toArray(servicesClassesArray);
        AppCenter.start(app, start_secret, servicesClassesArray);
        result.success(null);
        break;

        // Analytics
      case "isEnabledAnalytics":
        Analytics.isEnabled().thenAccept(new AppCenterConsumer<Boolean>() {
          @Override
          public void accept(Boolean enabled) {
            result.success(enabled.booleanValue());
          }
        });

        break;
      case "setEnabledAnalytics":
        Boolean isEnabledAnalytics = call.argument("isEnabled");
        Analytics.setEnabled(isEnabledAnalytics).thenAccept(new AppCenterConsumer<Void>() {
          @Override
          public void accept(Void v) {
            result.success(null);
          }
        });
        break;
      case "trackEvent":
        String name = call.argument("name");
        Map<String, String> properties = call.argument("properties");
        Analytics.trackEvent(name, properties);
        break;

        /// Crashes
      case "isEnabledCrashes":
        Crashes.isEnabled().thenAccept(new AppCenterConsumer<Boolean>() {
          @Override
          public void accept(Boolean enabled) {
            result.success(enabled.booleanValue());
          }
        });
        break;
      case "setEnabledCrashes":
        Boolean isEnabledCrashes = call.argument("isEnabled");
        Crashes.setEnabled(isEnabledCrashes).thenAccept(new AppCenterConsumer<Void>() {
          @Override
          public void accept(Void v) {
            result.success(null);
          }
        });
        break;
      case "generateTestCrash":
        Crashes.generateTestCrash();
        result.success(0);
        break;

      default:
        result.notImplemented();
        break;
    }
  }

  @Override
  public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
    channel.setMethodCallHandler(null);
  }
}

==> 0.0.3.tar.gz: android/src/main/java/com/mobcodes/microsoft_appcenter_flutter/MicrosoftAppcenterFlutterPlugin.java <==
package com.mobcodes.microsoft_appcenter_flutter;

import android.app.Activity;
import android.app.Application;

import androidx.annotation.NonNull;

import com.microsoft.appcenter.AppCenter;
import com.microsoft.appcenter.analytics.Analytics;
import com.microsoft.appcenter.crashes.Crashes;
import com.microsoft.appcenter.utils.async.AppCenterConsumer;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.UUID;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.embedding.engine.plugins.activity.ActivityAware;
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;

/** MicrosoftAppcenterFlutterPlugin */
public class MicrosoftAppcenterFlutterPlugin implements FlutterPlugin, MethodCallHandler, ActivityAware {
  /// The MethodChannel that will the communication between Flutter and native Android
  ///
  /// This local reference serves to register the plugin with the Flutter Engine and unregister it
  /// when the Flutter Engine is detached from the Activity
  private MethodChannel channel;
  private Activity activity;

  @Override
  public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
    channel = new MethodChannel(flutterPluginBinding.getBinaryMessenger(), "microsoft_appcenter_flutter");
    channel.setMethodCallHandler(this);
  }

  @Override
  public void onMethodCall(@NonNull MethodCall call, @NonNull final Result result) {
    if (call.method.equals("getPlatformVersion")) {
      result.success("Android " + android.os.Build.VERSION.RELEASE);
    } else {
      result.notImplemented();
    }

    Application app = this.activity.getApplication();

    switch (call.method) {
      case "installId":
        AppCenter.getInstallId().thenAccept(new AppCenterConsumer<UUID>() {
          @Override
          public void accept(UUID uuid) {
            result.success(uuid.toString());
          }
        });

        break;
      case "isEnabled":
        AppCenter.isEnabled().thenAccept(new AppCenterConsumer<Boolean>() {
          @Override
          public void accept(Boolean enabled) {
            result.success(enabled.booleanValue());
          }
        });

        break;
      case "setEnabled":
        Boolean isEnabled = call.argument("isEnabled");
        AppCenter.setEnabled(isEnabled).thenAccept(new AppCenterConsumer<Void>() {
          @Override
          public void accept(Void v) {
            result.success(null);
          }
        });
        break;
      case "configure":
        String secret = call.argument("app_secret");
        AppCenter.configure(app, secret);
        result.success(null);
        break;
      case "start":
        String start_secret = call.argument("app_secret");
        List<String> services = call.argument("services");
        List<Class> servicesClasses = new ArrayList<>();
        for (String name : services) {
          try {
            Class c = Class.forName(name);
            servicesClasses.add(c);
          }
          catch(ClassNotFoundException notFound) {
            System.out.print(notFound.getException().toString());
          }
        }

        Class[] servicesClassesArray = new Class[servicesClasses.size()];
        servicesClassesArray = servicesClasses.toArray(servicesClassesArray);
        AppCenter.start(app, start_secret, servicesClassesArray);
        result.success(null);
        break;

        // Analytics
      case "isEnabledAnalytics":
        Analytics.isEnabled().thenAccept(new AppCenterConsumer<Boolean>() {
          @Override
          public void accept(Boolean enabled) {
            result.success(enabled.booleanValue());
          }
        });

        break;
      case "setEnabledAnalytics":
        Boolean isEnabledAnalytics = call.argument("isEnabled");
        Analytics.setEnabled(isEnabledAnalytics).thenAccept(new AppCenterConsumer<Void>() {
          @Override
          public void accept(Void v) {
            result.success(null);
          }
        });
        break;
      case "trackEvent":
        String name = call.argument("name");
        Map<String, String> properties = call.argument("properties");
        Analytics.trackEvent(name, properties);
        break;

        /// Crashes
      case "isEnabledCrashes":
        Crashes.isEnabled().thenAccept(new AppCenterConsumer<Boolean>() {
          @Override
          public void accept(Boolean enabled) {
            result.success(enabled.booleanValue());
          }
        });
        break;
      case "setEnabledCrashes":
        Boolean isEnabledCrashes = call.argument("isEnabled");
        Crashes.setEnabled(isEnabledCrashes).thenAccept(new AppCenterConsumer<Void>() {
          @Override
          public void accept(Void v) {
            result.success(null);
          }
        });
        break;
      case "generateTestCrash":
        Crashes.generateTestCrash();
        result.success(0);
        break;

      default:
        result.notImplemented();
        break;
    }
  }

  @Override
  public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
    channel.setMethodCallHandler(null);
  }

  @Override
  public void onAttachedToActivity(@NonNull ActivityPluginBinding binding) {
    this.activity = binding.getActivity();
  }

  @Override
  public void onDetachedFromActivityForConfigChanges() {

  }

  @Override
  public void onReattachedToActivityForConfigChanges(@NonNull ActivityPluginBinding binding) {

  }

  @Override
  public void onDetachedFromActivity() {

  }
}
